@@ -7,6 +7,7 @@
 // https://docs.nvidia.com/deploy/nvml-api/group__nvmlDeviceStructs.html
 #define NVML_DEVICE_PCI_BUS_ID_BUFFER_SIZE 32
 #define NVML_DEVICE_PCI_BUS_ID_BUFFER_V2_SIZE 16
+#define NVML_DEVICE_NAME_V2_BUFFER_SIZE 96
 
 typedef enum { NVML_SUCCESS = 0 } nvmlReturn_t;
 typedef struct nvmlDevice_t* nvmlDevice_t;
@@ -94,6 +95,16 @@ typedef enum {
     NVML_BRAND_COUNT,
 } nvmlBrandType_t;
 
+// https://docs.nvidia.com/deploy/nvml-api/structnvmlUtilization__t.html#structnvmlUtilization__t
+// Utilization information for a device.
+typedef struct
+{
+    // Percent of time over the past second during which one or more kernels was executing on the GPU
+    unsigned int gpu;
+    // Percent of time over the past second during which global (device) memory was being read or written
+    unsigned int memory;
+} nvmlUtilization_t;
+
 // https://docs.nvidia.com/deploy/nvml-api/group__nvmlInitializationAndCleanup.html#group__nvmlInitializationAndCleanup
 // Initialize NVML, but don't initialize any GPUs yet
 nvmlReturn_t nvmlInit_v2(void);
@@ -119,3 +130,7 @@ extern nvmlReturn_t nvmlDeviceGetNumGpuCores(nvmlDevice_t device, unsigned int*
 extern nvmlReturn_t nvmlDeviceGetMaxClockInfo(nvmlDevice_t device, nvmlClockType_t type, unsigned int* clock);
 // Retrieves the brand of this device
 extern nvmlReturn_t nvmlDeviceGetBrand(nvmlDevice_t device, nvmlBrandType_t* type);
+// Retrieves the current utilization rates for the device
+extern nvmlReturn_t nvmlDeviceGetUtilizationRates(nvmlDevice_t device, nvmlUtilization_t *utilization);
+// Retrieves the name of this device.
+extern nvmlReturn_t nvmlDeviceGetName(nvmlDevice_t device, char *name, unsigned int length);
